@@ -31,7 +31,6 @@
 #include <KLocalizedString>
 #include <QColorDialog>
 #include <QTextBlock>
-#include <QCoreApplication>
 #include <QTimer>
 #include <QPointer>
 #include <QClipboard>
@@ -903,7 +902,7 @@ QString RichTextComposerControler::toWrappedPlainText() const
 QString RichTextComposerControler::toWrappedPlainText(QTextDocument *doc) const
 {
     QString temp;
-    QRegularExpression rx(QLatin1String("(http|ftp|ldap)s?\\S+-$"));
+    QRegularExpression rx(QStringLiteral("(http|ftp|ldap)s?\\S+-$"));
     QTextBlock block = doc->begin();
     while (block.isValid()) {
         QTextLayout *layout = block.layout();
