@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -40,12 +40,12 @@ public:
     };
     Q_ENUMS(State)
 
-    State state() const;
+    Q_REQUIRED_RESULT State state() const;
     void setState(KPIMTextEdit::TextToSpeechWidget::State state);
 
     void setTextToSpeechInterface(AbstractTextToSpeechInterface *interface);
 
-    bool isReady() const;
+    Q_REQUIRED_RESULT bool isReady() const;
 
 public Q_SLOTS:
     void say(const QString &text);
